# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import spaces_pb2 as spaces__pb2


class SpacesStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSpace = channel.unary_unary(
                '/dialog.Spaces/CreateSpace',
                request_serializer=spaces__pb2.RequestCreateSpace.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpace.FromString,
                )
        self.DeleteSpace = channel.unary_unary(
                '/dialog.Spaces/DeleteSpace',
                request_serializer=spaces__pb2.RequestDeleteSpace.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpace.FromString,
                )
        self.SetTitle = channel.unary_unary(
                '/dialog.Spaces/SetTitle',
                request_serializer=spaces__pb2.RequestSetTitle.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpace.FromString,
                )
        self.SetShortname = channel.unary_unary(
                '/dialog.Spaces/SetShortname',
                request_serializer=spaces__pb2.RequestSetShortname.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpace.FromString,
                )
        self.SetAbout = channel.unary_unary(
                '/dialog.Spaces/SetAbout',
                request_serializer=spaces__pb2.RequestSetAbout.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpace.FromString,
                )
        self.SetAvatar = channel.unary_unary(
                '/dialog.Spaces/SetAvatar',
                request_serializer=spaces__pb2.RequestSetAvatar.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpace.FromString,
                )
        self.LoadSpaces = channel.unary_unary(
                '/dialog.Spaces/LoadSpaces',
                request_serializer=spaces__pb2.RequestLoadSpaces.SerializeToString,
                response_deserializer=spaces__pb2.ResponseLoadSpaces.FromString,
                )
        self.LoadSpaceMembers = channel.unary_stream(
                '/dialog.Spaces/LoadSpaceMembers',
                request_serializer=spaces__pb2.RequestStreamSpaceMembers.SerializeToString,
                response_deserializer=spaces__pb2.SpaceMemberWithPeer.FromString,
                )
        self.Invite = channel.unary_unary(
                '/dialog.Spaces/Invite',
                request_serializer=spaces__pb2.RequestSpaceInvite.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpaceMember.FromString,
                )
        self.Kick = channel.unary_unary(
                '/dialog.Spaces/Kick',
                request_serializer=spaces__pb2.RequestSpaceKick.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpaceMember.FromString,
                )
        self.Leave = channel.unary_unary(
                '/dialog.Spaces/Leave',
                request_serializer=spaces__pb2.RequestSpaceLeave.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpaceMember.FromString,
                )
        self.GetSpaceInviteUrl = channel.unary_unary(
                '/dialog.Spaces/GetSpaceInviteUrl',
                request_serializer=spaces__pb2.RequestGetSpaceInviteUrl.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpaceInviteUrl.FromString,
                )
        self.RevokeSpaceInviteUrl = channel.unary_unary(
                '/dialog.Spaces/RevokeSpaceInviteUrl',
                request_serializer=spaces__pb2.RequestRevokeSpaceInviteUrl.SerializeToString,
                response_deserializer=spaces__pb2.ResponseSpaceInviteUrl.FromString,
                )


class SpacesServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateSpace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteSpace(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetTitle(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetShortname(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAbout(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetAvatar(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadSpaces(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadSpaceMembers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Invite(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Kick(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Leave(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSpaceInviteUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RevokeSpaceInviteUrl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SpacesServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSpace': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSpace,
                    request_deserializer=spaces__pb2.RequestCreateSpace.FromString,
                    response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
            ),
            'DeleteSpace': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteSpace,
                    request_deserializer=spaces__pb2.RequestDeleteSpace.FromString,
                    response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
            ),
            'SetTitle': grpc.unary_unary_rpc_method_handler(
                    servicer.SetTitle,
                    request_deserializer=spaces__pb2.RequestSetTitle.FromString,
                    response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
            ),
            'SetShortname': grpc.unary_unary_rpc_method_handler(
                    servicer.SetShortname,
                    request_deserializer=spaces__pb2.RequestSetShortname.FromString,
                    response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
            ),
            'SetAbout': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAbout,
                    request_deserializer=spaces__pb2.RequestSetAbout.FromString,
                    response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
            ),
            'SetAvatar': grpc.unary_unary_rpc_method_handler(
                    servicer.SetAvatar,
                    request_deserializer=spaces__pb2.RequestSetAvatar.FromString,
                    response_serializer=spaces__pb2.ResponseSpace.SerializeToString,
            ),
            'LoadSpaces': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadSpaces,
                    request_deserializer=spaces__pb2.RequestLoadSpaces.FromString,
                    response_serializer=spaces__pb2.ResponseLoadSpaces.SerializeToString,
            ),
            'LoadSpaceMembers': grpc.unary_stream_rpc_method_handler(
                    servicer.LoadSpaceMembers,
                    request_deserializer=spaces__pb2.RequestStreamSpaceMembers.FromString,
                    response_serializer=spaces__pb2.SpaceMemberWithPeer.SerializeToString,
            ),
            'Invite': grpc.unary_unary_rpc_method_handler(
                    servicer.Invite,
                    request_deserializer=spaces__pb2.RequestSpaceInvite.FromString,
                    response_serializer=spaces__pb2.ResponseSpaceMember.SerializeToString,
            ),
            'Kick': grpc.unary_unary_rpc_method_handler(
                    servicer.Kick,
                    request_deserializer=spaces__pb2.RequestSpaceKick.FromString,
                    response_serializer=spaces__pb2.ResponseSpaceMember.SerializeToString,
            ),
            'Leave': grpc.unary_unary_rpc_method_handler(
                    servicer.Leave,
                    request_deserializer=spaces__pb2.RequestSpaceLeave.FromString,
                    response_serializer=spaces__pb2.ResponseSpaceMember.SerializeToString,
            ),
            'GetSpaceInviteUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSpaceInviteUrl,
                    request_deserializer=spaces__pb2.RequestGetSpaceInviteUrl.FromString,
                    response_serializer=spaces__pb2.ResponseSpaceInviteUrl.SerializeToString,
            ),
            'RevokeSpaceInviteUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.RevokeSpaceInviteUrl,
                    request_deserializer=spaces__pb2.RequestRevokeSpaceInviteUrl.FromString,
                    response_serializer=spaces__pb2.ResponseSpaceInviteUrl.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Spaces', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Spaces(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateSpace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/CreateSpace',
            spaces__pb2.RequestCreateSpace.SerializeToString,
            spaces__pb2.ResponseSpace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteSpace(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/DeleteSpace',
            spaces__pb2.RequestDeleteSpace.SerializeToString,
            spaces__pb2.ResponseSpace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetTitle(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/SetTitle',
            spaces__pb2.RequestSetTitle.SerializeToString,
            spaces__pb2.ResponseSpace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetShortname(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/SetShortname',
            spaces__pb2.RequestSetShortname.SerializeToString,
            spaces__pb2.ResponseSpace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAbout(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/SetAbout',
            spaces__pb2.RequestSetAbout.SerializeToString,
            spaces__pb2.ResponseSpace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetAvatar(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/SetAvatar',
            spaces__pb2.RequestSetAvatar.SerializeToString,
            spaces__pb2.ResponseSpace.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadSpaces(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/LoadSpaces',
            spaces__pb2.RequestLoadSpaces.SerializeToString,
            spaces__pb2.ResponseLoadSpaces.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadSpaceMembers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(request, target, '/dialog.Spaces/LoadSpaceMembers',
            spaces__pb2.RequestStreamSpaceMembers.SerializeToString,
            spaces__pb2.SpaceMemberWithPeer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Invite(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/Invite',
            spaces__pb2.RequestSpaceInvite.SerializeToString,
            spaces__pb2.ResponseSpaceMember.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Kick(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/Kick',
            spaces__pb2.RequestSpaceKick.SerializeToString,
            spaces__pb2.ResponseSpaceMember.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Leave(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/Leave',
            spaces__pb2.RequestSpaceLeave.SerializeToString,
            spaces__pb2.ResponseSpaceMember.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSpaceInviteUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/GetSpaceInviteUrl',
            spaces__pb2.RequestGetSpaceInviteUrl.SerializeToString,
            spaces__pb2.ResponseSpaceInviteUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RevokeSpaceInviteUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Spaces/RevokeSpaceInviteUrl',
            spaces__pb2.RequestRevokeSpaceInviteUrl.SerializeToString,
            spaces__pb2.ResponseSpaceInviteUrl.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: definitions.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .scalapb import scalapb_pb2 as scalapb_dot_scalapb__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='definitions.proto',
  package='dialog',
  syntax='proto3',
  serialized_options=b'\n\024im.dlg.grpc.servicesZ\006dialog',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x11\x64\x65\x66initions.proto\x12\x06\x64ialog\x1a\x15scalapb/scalapb.proto\x1a google/protobuf/descriptor.proto\"%\n\tUUIDValue\x12\x0b\n\x03msb\x18\x01 \x01(\x03\x12\x0b\n\x03lsb\x18\x02 \x01(\x03\".\n\rDialogOptions\x12\x0b\n\x03log\x18\x01 \x01(\t\x12\x10\n\x08required\x18\x02 \x01(\x08\"\x1a\n\tDataClock\x12\r\n\x05\x63lock\x18\x01 \x01(\x03:C\n\x03\x64lg\x12\x1d.google.protobuf.FieldOptions\x18\xa1\x8d\x06 \x01(\x0b\x32\x15.dialog.DialogOptionsB\x1e\n\x14im.dlg.grpc.servicesZ\x06\x64ialogb\x06proto3'
  ,
  dependencies=[scalapb_dot_scalapb__pb2.DESCRIPTOR,google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


DLG_FIELD_NUMBER = 100001
dlg = _descriptor.FieldDescriptor(
  name='dlg', full_name='dialog.dlg', index=0,
  number=100001, type=11, cpp_type=10, label=1,
  has_default_value=False, default_value=None,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)


_UUIDVALUE = _descriptor.Descriptor(
  name='UUIDValue',
  full_name='dialog.UUIDValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='msb', full_name='dialog.UUIDValue.msb', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lsb', full_name='dialog.UUIDValue.lsb', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=86,
  serialized_end=123,
)


_DIALOGOPTIONS = _descriptor.Descriptor(
  name='DialogOptions',
  full_name='dialog.DialogOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='log', full_name='dialog.DialogOptions.log', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='required', full_name='dialog.DialogOptions.required', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=171,
)


_DATACLOCK = _descriptor.Descriptor(
  name='DataClock',
  full_name='dialog.DataClock',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='clock', full_name='dialog.DataClock.clock', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=173,
  serialized_end=199,
)

DESCRIPTOR.message_types_by_name['UUIDValue'] = _UUIDVALUE
DESCRIPTOR.message_types_by_name['DialogOptions'] = _DIALOGOPTIONS
DESCRIPTOR.message_types_by_name['DataClock'] = _DATACLOCK
DESCRIPTOR.extensions_by_name['dlg'] = dlg
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UUIDValue = _reflection.GeneratedProtocolMessageType('UUIDValue', (_message.Message,), {
  'DESCRIPTOR' : _UUIDVALUE,
  '__module__' : 'definitions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.UUIDValue)
  })
_sym_db.RegisterMessage(UUIDValue)

DialogOptions = _reflection.GeneratedProtocolMessageType('DialogOptions', (_message.Message,), {
  'DESCRIPTOR' : _DIALOGOPTIONS,
  '__module__' : 'definitions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DialogOptions)
  })
_sym_db.RegisterMessage(DialogOptions)

DataClock = _reflection.GeneratedProtocolMessageType('DataClock', (_message.Message,), {
  'DESCRIPTOR' : _DATACLOCK,
  '__module__' : 'definitions_pb2'
  # @@protoc_insertion_point(class_scope:dialog.DataClock)
  })
_sym_db.RegisterMessage(DataClock)

dlg.message_type = _DIALOGOPTIONS
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(dlg)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import search_pb2 as search__pb2


class SearchStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.PeerSearch = channel.unary_unary(
                '/dialog.Search/PeerSearch',
                request_serializer=search__pb2.RequestPeerSearch.SerializeToString,
                response_deserializer=search__pb2.ResponsePeerSearch.FromString,
                )
        self.ResolvePeer = channel.unary_unary(
                '/dialog.Search/ResolvePeer',
                request_serializer=search__pb2.RequestResolvePeer.SerializeToString,
                response_deserializer=search__pb2.ResponseResolvePeer.FromString,
                )
        self.MessageSearch = channel.unary_unary(
                '/dialog.Search/MessageSearch',
                request_serializer=search__pb2.RequestMessageSearch.SerializeToString,
                response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
                )
        self.MessageSearchMore = channel.unary_unary(
                '/dialog.Search/MessageSearchMore',
                request_serializer=search__pb2.RequestMessageSearchMore.SerializeToString,
                response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
                )
        self.SimpleSearch = channel.unary_unary(
                '/dialog.Search/SimpleSearch',
                request_serializer=search__pb2.RequestSimpleSearch.SerializeToString,
                response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
                )
        self.SimpleSearchMore = channel.unary_unary(
                '/dialog.Search/SimpleSearchMore',
                request_serializer=search__pb2.RequestSimpleSearchMore.SerializeToString,
                response_deserializer=search__pb2.ResponseMessageSearchResponse.FromString,
                )
        self.AutocompleteSuggestions = channel.unary_unary(
                '/dialog.Search/AutocompleteSuggestions',
                request_serializer=search__pb2.RequestFieldAutocomplete.SerializeToString,
                response_deserializer=search__pb2.ResponseFieldAutocomplete.FromString,
                )
        self.LoadUserSearchByPredicatesResults = channel.unary_unary(
                '/dialog.Search/LoadUserSearchByPredicatesResults',
                request_serializer=search__pb2.RequestLoadUserSearchByPredicatesResults.SerializeToString,
                response_deserializer=search__pb2.ResponseLoadUserSearchByPredicatesResults.FromString,
                )
        self.LoadUserSearchByPredicatesCount = channel.unary_unary(
                '/dialog.Search/LoadUserSearchByPredicatesCount',
                request_serializer=search__pb2.RequestLoadUserSearchByPredicatesCount.SerializeToString,
                response_deserializer=search__pb2.ResponseLoadUserSearchByPredicatesCount.FromString,
                )
        self.GetRecommendations = channel.unary_unary(
                '/dialog.Search/GetRecommendations',
                request_serializer=search__pb2.RequestGetRecommendations.SerializeToString,
                response_deserializer=search__pb2.ResponseGetRecommendations.FromString,
                )
        self.GetPromotedPeers = channel.unary_unary(
                '/dialog.Search/GetPromotedPeers',
                request_serializer=search__pb2.RequestGetPromotedPeers.SerializeToString,
                response_deserializer=search__pb2.ResponseGetPromotedPeers.FromString,
                )


class SearchServicer(object):
    """Missing associated documentation comment in .proto file."""

    def PeerSearch(self, request, context):
        """/ Search among groups/users/contacts
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolvePeer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageSearch(self, request, context):
        """/ Search by messages
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def MessageSearchMore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimpleSearch(self, request, context):
        """/ Custom search by conditions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SimpleSearchMore(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AutocompleteSuggestions(self, request, context):
        """/ Search for autocomplete suggestions among custom user profile
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadUserSearchByPredicatesResults(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoadUserSearchByPredicatesCount(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetRecommendations(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetPromotedPeers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SearchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'PeerSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.PeerSearch,
                    request_deserializer=search__pb2.RequestPeerSearch.FromString,
                    response_serializer=search__pb2.ResponsePeerSearch.SerializeToString,
            ),
            'ResolvePeer': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolvePeer,
                    request_deserializer=search__pb2.RequestResolvePeer.FromString,
                    response_serializer=search__pb2.ResponseResolvePeer.SerializeToString,
            ),
            'MessageSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageSearch,
                    request_deserializer=search__pb2.RequestMessageSearch.FromString,
                    response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
            ),
            'MessageSearchMore': grpc.unary_unary_rpc_method_handler(
                    servicer.MessageSearchMore,
                    request_deserializer=search__pb2.RequestMessageSearchMore.FromString,
                    response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
            ),
            'SimpleSearch': grpc.unary_unary_rpc_method_handler(
                    servicer.SimpleSearch,
                    request_deserializer=search__pb2.RequestSimpleSearch.FromString,
                    response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
            ),
            'SimpleSearchMore': grpc.unary_unary_rpc_method_handler(
                    servicer.SimpleSearchMore,
                    request_deserializer=search__pb2.RequestSimpleSearchMore.FromString,
                    response_serializer=search__pb2.ResponseMessageSearchResponse.SerializeToString,
            ),
            'AutocompleteSuggestions': grpc.unary_unary_rpc_method_handler(
                    servicer.AutocompleteSuggestions,
                    request_deserializer=search__pb2.RequestFieldAutocomplete.FromString,
                    response_serializer=search__pb2.ResponseFieldAutocomplete.SerializeToString,
            ),
            'LoadUserSearchByPredicatesResults': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadUserSearchByPredicatesResults,
                    request_deserializer=search__pb2.RequestLoadUserSearchByPredicatesResults.FromString,
                    response_serializer=search__pb2.ResponseLoadUserSearchByPredicatesResults.SerializeToString,
            ),
            'LoadUserSearchByPredicatesCount': grpc.unary_unary_rpc_method_handler(
                    servicer.LoadUserSearchByPredicatesCount,
                    request_deserializer=search__pb2.RequestLoadUserSearchByPredicatesCount.FromString,
                    response_serializer=search__pb2.ResponseLoadUserSearchByPredicatesCount.SerializeToString,
            ),
            'GetRecommendations': grpc.unary_unary_rpc_method_handler(
                    servicer.GetRecommendations,
                    request_deserializer=search__pb2.RequestGetRecommendations.FromString,
                    response_serializer=search__pb2.ResponseGetRecommendations.SerializeToString,
            ),
            'GetPromotedPeers': grpc.unary_unary_rpc_method_handler(
                    servicer.GetPromotedPeers,
                    request_deserializer=search__pb2.RequestGetPromotedPeers.FromString,
                    response_serializer=search__pb2.ResponseGetPromotedPeers.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'dialog.Search', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Search(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def PeerSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/PeerSearch',
            search__pb2.RequestPeerSearch.SerializeToString,
            search__pb2.ResponsePeerSearch.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResolvePeer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/ResolvePeer',
            search__pb2.RequestResolvePeer.SerializeToString,
            search__pb2.ResponseResolvePeer.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/MessageSearch',
            search__pb2.RequestMessageSearch.SerializeToString,
            search__pb2.ResponseMessageSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def MessageSearchMore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/MessageSearchMore',
            search__pb2.RequestMessageSearchMore.SerializeToString,
            search__pb2.ResponseMessageSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimpleSearch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/SimpleSearch',
            search__pb2.RequestSimpleSearch.SerializeToString,
            search__pb2.ResponseMessageSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SimpleSearchMore(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/SimpleSearchMore',
            search__pb2.RequestSimpleSearchMore.SerializeToString,
            search__pb2.ResponseMessageSearchResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AutocompleteSuggestions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/AutocompleteSuggestions',
            search__pb2.RequestFieldAutocomplete.SerializeToString,
            search__pb2.ResponseFieldAutocomplete.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadUserSearchByPredicatesResults(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/LoadUserSearchByPredicatesResults',
            search__pb2.RequestLoadUserSearchByPredicatesResults.SerializeToString,
            search__pb2.ResponseLoadUserSearchByPredicatesResults.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoadUserSearchByPredicatesCount(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/LoadUserSearchByPredicatesCount',
            search__pb2.RequestLoadUserSearchByPredicatesCount.SerializeToString,
            search__pb2.ResponseLoadUserSearchByPredicatesCount.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetRecommendations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/GetRecommendations',
            search__pb2.RequestGetRecommendations.SerializeToString,
            search__pb2.ResponseGetRecommendations.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetPromotedPeers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/dialog.Search/GetPromotedPeers',
            search__pb2.RequestGetPromotedPeers.SerializeToString,
            search__pb2.ResponseGetPromotedPeers.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
